require 'spec_helper'

RSpec.describe ProductAggregator::Connection, :type => :model do

  subject { described_class }

  before do
    allow(ProductAggregator.configuration).to receive(:max_retry).and_return(1)
  end

  it { is_expected.to respond_to(:get_product) }

  describe '#get_product' do
    let(:data) { { id: 123, name: 'Product kecantikan' } }
    let(:data_other) { { id: 456, name: 'Product kesehatan' } }
    let(:response) { { data: data }.to_json }
    let(:response_other) { { data: data_other }.to_json }
    let(:not_found) { {errors: [{ message: 'Product tidak ditemukann' }] }.to_json }
    let(:server_error) { {errors: [{ message: 'Ada kesalahan pada sistem' }] }.to_json }
    let(:unauthorized) { {errors: [{ message: 'Unauthorized' }] }.to_json }
    let(:other_error) { {errors: [{ message: 'Kesalahan lainnya' }] }.to_json }

    # context 'success response' do
    #   before do
    #     stub_request(:get, 'http://localhost:8027/_internal/products/1?origin=readonly').to_return({ status: 200, body: response })
    #     stub_request(:get, 'http://localhost:8027/_internal/products/2?origin=master').to_return({ status: 200, body: response_other })
    #   end

    #   it do
    #     expect(subject.get_product(1)).to eq({ 'id' => 123, 'name' => 'Product kecantikan' })
    #     expect(subject.get_product(2, 'master')).to eq({ 'id' => 456, 'name' => 'Product kesehatan' })
    #   end
    # end

    context '404 response' do
      before { stub_request(:get, 'http://localhost:8027/_internal/products/1?origin=readonly').to_return({ status: 404, body: not_found }) }

      it { expect(subject.get_product(1)).to raise_error(ProductAggregator::NotFoundError) }
    end

    context 'timeout' do
      before { stub_request(:get, 'http://localhost:8027/_internal/products/1?origin=readonly').to_timeout }

      it { expect{subject.get_product(1)}.to raise_error }
    end
  end
end
